Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
Types ¶
type InstrumentationLibrary ¶
type Nodes ¶
type Nodes []*SnapshotNode
type SnapshotNode ¶
type SnapshotNode struct {
SpanSnapshot *SpanSnapshot
Children Nodes
}
SnapshotNode represents the tree of traces. Each trace may have multiple children but a single parent.
func ToTree ¶
func ToTree(spans []*SpanSnapshot) *SnapshotNode
type SpanContext ¶
type SpanSnapshot ¶
type SpanSnapshot struct {
SpanContext SpanContext
Parent SpanContext
SpanKind int
Name string
StartTime time.Time
EndTime time.Time
Attributes []KeyValue
MessageEvents interface{} // ???
Links interface{} // ???
StatusCode string
StatusMessage string
DroppedAttributeCount int
DroppedMessageEventCount int
DroppedLinkCount int
ChildSpanCount int
Resource []KeyValue
InstrumentationLibrary InstrumentationLibrary
}
SpanSnapshot allows unmarshalling the stdout exporter data. This is based on the output currently returned by the stdout exporter as the structs used by the exporter do not unmarshal back to the same struct. There are no guarantees that this structure won't change in the future.
See https://github.com/open-telemetry/opentelemetry-go/issues/1819#issuecomment-825798804
type TraceGraph ¶
TraceGraph implements the tview primative for displaying traces
func NewTraceGraph ¶
func NewTraceGraph(traces []*Trace, text *tview.TextView) *TraceGraph
func (*TraceGraph) Draw ¶
func (t *TraceGraph) Draw(screen tcell.Screen)
func (*TraceGraph) InputHandler ¶
func (t *TraceGraph) InputHandler() func(event *tcell.EventKey, setFocus func(p tview.Primitive))
func (*TraceGraph) MouseHandler ¶
func (t *TraceGraph) MouseHandler() func(action tview.MouseAction, event *tcell.EventMouse, setFocus func(p tview.Primitive)) (consumed bool, capture tview.Primitive)
Click to show internal directories.
Click to hide internal directories.